create table sscOrder (
	orderID int4 not null, 
	class varchar(255) not null DEFAULT 'com.softslate.commerce.businessobjects.order.OrderBean', 
	customerID int4, 
	userName varchar(100), 
	orderNumber int4, 
	trackingNumber varchar(100), 
	total float8, 
	shipping float8, 
	tax float8, 
	taxableSubtotal float8, 
	subtotal float8, 
	weight float8, 
	quantity int4, 
	created varchar(100), 
	lastModified varchar(100), 
	completed varchar(100), 
	autoSavedCartToken varchar(255), 
	status varchar(100), 
	statusDetails varchar(255), 
	shippingMethod varchar(255), 
	firstName varchar(100), 
	lastName varchar(100), 
	organization varchar(100), 
	address1 varchar(255), 
	address2 varchar(255), 
	city varchar(100), 
	state varchar(100), 
	postalCode varchar(100), 
	country varchar(100), 
	phone1 varchar(100), 
	phone2 varchar(100), 
	email1 varchar(100), 
	email2 varchar(100), 
	paymentProfileID varchar(100),
	extra1 varchar(255), 
	extra2 varchar(255), 
	extra3 varchar(255), 
	extra4 varchar(255), 
	extra5 varchar(255), 
	notes text, 
	primary key (orderID)
);

CREATE SEQUENCE orderNumberSequence;

CREATE TABLE sscOrderNumber (
	orderNumber int4 not null default nextval('orderNumberSequence'::text), 
	class varchar(255) not null DEFAULT 'com.softslate.commerce.businessobjects.order.OrderNumberBean', 
	primary key (orderNumber)
);

create table sscOrderDelivery (
	orderDeliveryID int4 not null, 
	class varchar(255) not null DEFAULT 'com.softslate.commerce.businessobjects.order.OrderDeliveryBean', 
	orderID int4, 
	trackingNumber varchar(100), 
	total float8, 
	shipping float8, 
	tax float8, 
	taxableSubtotal float8, 
	subtotal float8, 
	weight float8, 
	quantity int4, 
	lastModified varchar(100), 
	delivered varchar(100), 
	status varchar(100), 
	statusDetails varchar(255), 
	firstName varchar(100), 
	lastName varchar(100), 
	organization varchar(100), 
	address1 varchar(255), 
	address2 varchar(255), 
	city varchar(100), 
	state varchar(100), 
	postalCode varchar(100), 
	country varchar(100), 
	phone1 varchar(100), 
	phone2 varchar(100), 
	email1 varchar(100), 
	email2 varchar(100), 
	extra1 varchar(255), 
	extra2 varchar(255), 
	extra3 varchar(255), 
	extra4 varchar(255), 
	extra5 varchar(255), 
	notes text, 
	primary key (orderDeliveryID)
);

create table sscOrderDiscount (
	orderDiscountID int4 not null, 
	class varchar(255) not null DEFAULT 'com.softslate.commerce.businessobjects.order.OrderDiscountBean', 
	orderID int4, 
	orderItemID int4, 
	total float8, 
	discountID int4, 
	code varchar(100) not null, 
	name varchar(255), 
	usersAppliesType varchar(32), 
	usersAppliesValue varchar(255), 
	itemsAppliesType varchar(32), 
	itemsAppliesValue varchar(255), 
	cartItemsType varchar(32), 
	cartItemsValue varchar(255), 
	rewardType varchar(32), 
	reward float8, 
	couponCode varchar(32), 
	floor float8, 
	ceiling float8, 
	extra1 varchar(255), 
	extra2 varchar(255), 
	extra3 varchar(255), 
	primary key (orderDiscountID)
);

create table sscOrderItem (
	orderItemID int4 not null, 
	class varchar(255) not null DEFAULT 'com.softslate.commerce.businessobjects.order.OrderItemBean', 
	orderDeliveryID int4, 
	orderID int4, 
	total float8, 
	weight float8, 
	costTotal float8, 
	quantity int4 not null, 
	productID int4, 
	manufacturerID int4, 
	code varchar(100) not null, 
	seoCode varchar(255), 
	name varchar(255), 
	isActive bool not null default false, 
	unitCost float8, 
	unitPrice float8, 
	altPrice float8, 
	productWeight float8, 
	isTaxed bool not null, 
	image varchar(255), 
	shortDescription varchar(255), 
	extra1 varchar(255), 
	extra2 varchar(255), 
	extra3 varchar(255), 
	extra4 varchar(255), 
	extra5 varchar(255), 
	decrementedSKUs text, 
	primary key (orderItemID)
);

create table sscOrderItemAttribute (
	orderItemAttributeID int4 not null, 
	class varchar(255) not null DEFAULT 'com.softslate.commerce.businessobjects.order.OrderItemAttributeBean', 
	orderItemID int4, 
	total float8, 
	weight float8, 
	costTotal float8, 
	attributeValue text not null, 
	attributeID int4, 
	attributeCode varchar(100) not null, 
	attributeName varchar(255), 
	attributeUnitCost float8, 
	attributeUnitPrice float8, 
	attributeAltPrice float8, 
	attributeWeight float8, 
	attributeImage varchar(255), 
	optionID int4, 
	optionCode varchar(100), 
	optionName varchar(255), 
	optionUnitCost float8, 
	optionUnitPrice float8, 
	optionAltPrice float8, 
	optionWeight float8, 
	optionImage varchar(255), 
	primary key (orderItemAttributeID)
);

CREATE SEQUENCE countryInstallerSequence;

create table sscCountry (
	countryID int4 not null default nextval('countryInstallerSequence'::text), 
	class varchar(255) not null DEFAULT 'com.softslate.commerce.businessobjects.order.CountryBean', 
	code varchar(255) not null unique, 
	name varchar(255), 
	isActive bool not null default false, 
	allowOtherStates bool not null default false, 
	countryOrder int4 not null default 0, 
	primary key (countryID)
);

create table sscState (
	stateID int4 not null default nextval('hibernate_sequence'::text), 
	class varchar(255) not null DEFAULT 'com.softslate.commerce.businessobjects.order.StateBean', 
	countryID int4, 
	code varchar(255) not null, 
	name varchar(255), 
	isActive bool not null default false, 
	stateOrder int4 not null default 0, 
	primary key (stateID),
	unique (countryID, code)
);

create table sscOrderSetting (
	orderSettingID int4 not null, 
	class varchar(255) not null DEFAULT 'com.softslate.commerce.businessobjects.order.OrderSettingBean', 
	orderID int4, 
	code varchar(100) not null, 
	name varchar(100), 
	description varchar(255), 
	type varchar(100), 
	valueType varchar(16) not null, 
	integerValue int4, 
	smallValue varchar(64), 
	mediumValue varchar(255), 
	textValue text, 
	primary key (orderSettingID),
	unique (orderID, code)
);

alter table sscOrderDelivery add constraint FKCD430942DA8BA36 foreign key (orderID) references sscOrder ON DELETE CASCADE;
alter table sscOrderDiscount add constraint FKAC76628FDA8BA36 foreign key (orderID) references sscOrder ON DELETE CASCADE;
alter table sscOrderItem add constraint FK60163F61DA8BA36 foreign key (orderID) references sscOrder ON DELETE CASCADE;
alter table sscOrderItem add constraint FK60163F613D10DE3E foreign key (orderDeliveryID) references sscOrderDelivery ON DELETE CASCADE;
alter table sscDiscount add constraint FKDOI foreign key (orderItemID) references sscOrderItem ON DELETE SET NULL;
alter table sscOrderItemAttribute add constraint FK738E483B3AE8A63C foreign key (orderItemID) references sscOrderItem ON DELETE CASCADE;
alter table sscState add constraint FK4C7D4712F5AE506 foreign key (countryID) references sscCountry ON DELETE CASCADE;
alter table sscOrderSetting add constraint FK_orderSetting foreign key (orderID) references sscOrder ON DELETE CASCADE;

CREATE INDEX IDX_sscOrder_userName ON sscOrder (userName);
CREATE INDEX IDX_sscOrder_orderNumber ON sscOrder (orderNumber);
CREATE INDEX IDX_sscOrder_trackingNumber ON sscOrder (trackingNumber);
CREATE INDEX IDX_sscOrder_firstName ON sscOrder (firstName);
CREATE INDEX IDX_sscOrder_lastName ON sscOrder (lastName);
CREATE INDEX IDX_sscOrder_address1 ON sscOrder (address1);
CREATE INDEX IDX_sscOrder_postalCode ON sscOrder (postalCode);
CREATE INDEX IDX_sscOrder_phone1 ON sscOrder (phone1);
CREATE INDEX IDX_sscOrder_email1 ON sscOrder (email1);
CREATE INDEX IDX_sscO_autoSavedCartToken ON sscOrder (autoSavedCartToken);
CREATE INDEX IDX_sscOrder_completed ON sscOrder (completed);

CREATE INDEX IDX_sscOrderDelivery_trackingNumber ON sscOrderDelivery (trackingNumber);
CREATE INDEX IDX_sscOrderDelivery_firstName ON sscOrderDelivery (firstName);
CREATE INDEX IDX_sscOrderDelivery_lastName ON sscOrderDelivery (lastName);
CREATE INDEX IDX_sscOrderDelivery_address1 ON sscOrderDelivery (address1);
CREATE INDEX IDX_sscOrderDelivery_postalCode ON sscOrderDelivery (postalCode);
CREATE INDEX IDX_sscOrderDelivery_phone1 ON sscOrderDelivery (phone1);
CREATE INDEX IDX_sscOrderDelivery_email1 ON sscOrderDelivery (email1);

CREATE INDEX IDX_sscOrderItem_code ON sscOrderItem (code);
CREATE INDEX IDX_sscOrderItem_name ON sscOrderItem (name);

CREATE INDEX IDX_sscOrderItemAttribute_code ON sscOrderItemAttribute (attributeCode);
CREATE INDEX IDX_sscOrderItemAttribute_name ON sscOrderItemAttribute (attributeName);
CREATE INDEX IDX_sscOrderItemAttribute_optionCode ON sscOrderItemAttribute (optionCode);
CREATE INDEX IDX_sscOrderItemAttribute_optionName ON sscOrderItemAttribute (optionName);

CREATE INDEX IDX_sscCountry_name ON sscCountry (name);
CREATE INDEX IDX_sscCountry_order ON sscCountry (countryOrder);

CREATE INDEX IDX_sscState_name ON sscState (name);
CREATE INDEX IDX_sscState_order ON sscState (stateOrder);

CREATE INDEX IDX_sscOrderDiscount_total ON sscOrderDiscount (total);
CREATE INDEX IDX_sscOrderDiscount_code ON sscOrderDiscount (code);
CREATE INDEX IDX_sscOrderDiscount_name ON sscOrderDiscount (name);
