package com.softslate.commerce.administrator.core;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

/**
 * Struts form class corresponding to requests to
 * "/administrator/UserSettingAddForm.do",
 * "/administrator/UserSettingEditForm.do", "/administrator/UserSettingAdd.do",
 * and "/administrator/UserSettingEdit.do". Provides properties corresponding to
 * the fields for a single setting record.
 * 
 * @author Jason McWilliams
 * 
 */
public class UserSettingAddEditForm extends BaseAdministratorForm {

	private static final long serialVersionUID = 3154715764821170314L;

	static Log log = LogFactory.getLog(UserSettingAddEditForm.class);

	private String settingID = null;

	private String code = null;

	private String name = null;

	private String description = null;

	private String type = null;

	private String valueType = null;

	private String integerValue = null;

	private String smallValue = null;

	private String mediumValue = null;

	private String textValue = null;

	public String getSettingID() {
		return settingID;
	}

	public void setSettingID(String settingID) {
		this.settingID = settingID;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getValueType() {
		return valueType;
	}

	public void setValueType(String valueType) {
		this.valueType = valueType;
	}

	public String getIntegerValue() {
		return integerValue;
	}

	public void setIntegerValue(String integerValue) {
		this.integerValue = integerValue;
	}

	public String getSmallValue() {
		return smallValue;
	}

	public void setSmallValue(String smallValue) {
		this.smallValue = smallValue;
	}

	public String getMediumValue() {
		return mediumValue;
	}

	public void setMediumValue(String mediumValue) {
		this.mediumValue = mediumValue;
	}

	public String getTextValue() {
		return textValue;
	}

	public void setTextValue(String textValue) {
		this.textValue = textValue;
	}

	public ActionErrors validate(ActionMapping mapping,
			HttpServletRequest request) {
		if (log.isDebugEnabled())
			log.debug("Starting validation.");
		initializeProperties(mapping, request);
		if (getCode() == null || getCode().equals("")) {
			getErrors().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.required", "Code"));
		}
		if (getName() == null || getName().equals("")) {
			getErrors().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.required", "Name"));
		}
		if (getType() == null || !getType().equals("USERDEFINED")) {
			getErrors().add(
					ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.detail",
							"This must be a USERDEFINED type"));
		}
		if (getValueType() == null
				|| (!getValueType().equals("integerValue")
						&& !getValueType().equals("smallValue")
						&& !getValueType().equals("mediumValue") && !getValueType()
						.equals("textValue"))) {
			getErrors()
					.add(
							ActionMessages.GLOBAL_MESSAGE,
							new ActionMessage("errors.detail",
									"Value type must be integerValue, smallValue, mediumValue, or textValue."));
		}
		if (getValueType() != null && !getValueType().equals("integerValue")
				&& getIntegerValue() != null && getIntegerValue().length() > 0
				&& !getIntegerValue().equals("0")) {
			getErrors()
					.add(
							ActionMessages.GLOBAL_MESSAGE,
							new ActionMessage("errors.detail",
									"An integer was entered but integer was not selected as the value type."));
		}
		if (getValueType() != null && !getValueType().equals("smallValue")
				&& getSmallValue() != null && getSmallValue().length() > 0) {
			getErrors()
					.add(
							ActionMessages.GLOBAL_MESSAGE,
							new ActionMessage("errors.detail",
									"A small value was entered but 'Small string' was not selected as the value type."));
		}
		if (getValueType() != null && !getValueType().equals("mediumValue")
				&& getMediumValue() != null && getMediumValue().length() > 0) {
			getErrors()
					.add(
							ActionMessages.GLOBAL_MESSAGE,
							new ActionMessage("errors.detail",
									"A medium value was entered but 'Medium string' was not selected as the value type."));
		}
		if (getValueType() != null && !getValueType().equals("textValue")
				&& getTextValue() != null && getTextValue().length() > 0) {
			getErrors()
					.add(
							ActionMessages.GLOBAL_MESSAGE,
							new ActionMessage("errors.detail",
									"A text value was entered but 'Text' was not selected as the value type."));
		}

		return getErrors();
	}
}
