package com.softslate.commerce.businessobjects.customer;

import java.io.Serializable;
import java.util.Collection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BaseBusinessObject;

/**
 * Object representing a customer's wish list within the system.
 * <code>CustomerWishListBean</code> is the default implementation of the
 * <code>CustomerWishList</code> interface for the application.
 * <p>
 * The database stores customer wish lists in the <code>sscCustomerWishlist</code>
 * table, and this interface can be used to represent a single row of that
 * table. The Hibernate configuration file
 * <code>CustomerWishListBean.hbm.xml</code> maps that table's columns to the
 * properties in this object.
 * 
 * @author Jason McWilliams
 * 
 */
@Audited
@AuditTable("AudCustomerWishList")
public class CustomerWishListBean extends BaseBusinessObject implements
		CustomerWishList, Serializable {

	private static final long serialVersionUID = -3302988012902820729L;

	static Log log = LogFactory.getLog(CustomerWishListBean.class);

	private int customerWishListID = 0;

	public int getCustomerWishListID() {
		return (this.customerWishListID);
	}

	public void setCustomerWishListID(int customerWishListID) {
		this.customerWishListID = customerWishListID;
	}

	private int customerID;

	public int getCustomerID() {
		return (this.customerID);
	}

	public void setCustomerID(int customerID) {
		this.customerID = customerID;
	}
	
	private Customer customer = null;
	
	public Customer getCustomer() {
		return customer;
	}

	public void setCustomer(Customer customer) {
		this.customer = customer;
	}
	
	private String name = null;

	public String getName() {
		return (this.name);
	}

	public void setName(String name) {
		this.name = name;
	}

	private String description = null;

	public String getDescription() {
		return (this.description);
	}

	public void setDescription(String description) {
		this.description = description;
	}

	private String created = null;

	public String getCreated() {
		return (this.created);
	}

	public void setCreated(String created) {
		this.created = created;
	}

	private String lastUpdated = null;

	public String getLastUpdated() {
		return (this.lastUpdated);
	}

	public void setLastUpdated(String lastUpdated) {
		this.lastUpdated = lastUpdated;
	}
	
	private Collection customerWishListProducts = null;

	public Collection getCustomerWishListProducts() {
		return (this.customerWishListProducts);
	}

	public void setCustomerWishListProducts(Collection customerWishListProducts) {
		this.customerWishListProducts = customerWishListProducts;
	}

	private Collection productListCollection = null;

	public Collection getProductListCollection() {
		return (this.productListCollection);
	}

	public void setProductListCollection(Collection productListCollection) {
		this.productListCollection = productListCollection;
	}
	
	private int itemsPerPage = 9;

	public int getItemsPerPage() {
		return (this.itemsPerPage);
	}

	public void setItemsPerPage(int itemsPerPage) {
		this.itemsPerPage = itemsPerPage;
	}

	private int firstRow = 1;

	public int getFirstRow() {
		return (this.firstRow);
	}

	public void setFirstRow(int firstRow) {
		this.firstRow = firstRow;
	}

	private int itemCount = 0;

	public int getItemCount() {
		return (this.itemCount);
	}

	public void setItemCount(int itemCount) {
		this.itemCount = itemCount;
	}
	
}
