package com.softslate.commerce.businessobjects.email;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.softslate.commerce.businessobjects.core.BaseBusinessProcessor;
import com.softslate.commerce.daos.email.EmailOptOutDAO;
import com.softslate.commerce.daos.email.EmailOptOutGatewayDAO;

public class BasicEmailOptOutProcessor extends BaseBusinessProcessor implements EmailOptOutProcessor {

    static Log log = LogFactory.getLog(BasicEmailOptOutProcessor.class);

    public Map loadEmailOptOutsAndCount(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName() + ": Loading EmailOptOuts and count");
        EmailOptOutGatewayDAO emailOptOutDAO =  getDaoFactory().createDAO(EmailOptOutGatewayDAO.class);
        return emailOptOutDAO.loadEmailOptOutsAndCount(parameters);
    }

    public Map addEmailOptOut(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName() + ": Adding EmailOptOut");
        Map results = new HashMap();
        EmailOptOut emailOptOut =  getBusinessObjectFactory().createObject(EmailOptOut.class);
        BeanUtils.copyProperties(emailOptOut, parameters);
        EmailOptOutDAO emailOptOutDAO =  getDaoFactory().createDAO(EmailOptOutDAO.class);
        emailOptOutDAO.setEmailOptOut(emailOptOut);
        emailOptOutDAO.insertEmailOptOut(true);
        results.put("newRecord", emailOptOutDAO.getEmailOptOut());
        return results;
    }

    public EmailOptOut loadEmailOptOutFromID(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName() + ": Loading EmailOptOut from id");
        EmailOptOut emailOptOut =  getBusinessObjectFactory().createObject(EmailOptOut.class);
        EmailOptOutDAO emailOptOutDAO =  getDaoFactory().createDAO(EmailOptOutDAO.class);
        BeanUtils.copyProperties(emailOptOut, parameters);
        emailOptOutDAO.setEmailOptOut(emailOptOut);
        emailOptOutDAO.loadEmailOptOutFromID();
        return emailOptOutDAO.getEmailOptOut();
    }

    public Map editEmailOptOut(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName() + ": Editing EmailOptOut");
        EmailOptOut emailOptOut = loadEmailOptOutFromID(parameters);
        BeanUtils.copyProperties(emailOptOut, parameters);
        EmailOptOutDAO emailOptOutDAO =  getDaoFactory()
                .createDAO(EmailOptOutDAO.class);
        emailOptOutDAO.setEmailOptOut(emailOptOut);
        emailOptOutDAO.updateEmailOptOut(true);
        Map results = new HashMap();
        results.put("updatedRecord", emailOptOutDAO.getEmailOptOut());
        return results;
    }

    public void editDeleteEmailOptOuts(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName() + ": Editing/deleting multiple EmailOptOuts");
        EmailOptOutGatewayDAO emailOptOutDAO =  getDaoFactory().createDAO(EmailOptOutGatewayDAO.class);
        emailOptOutDAO.editDeleteEmailOptOuts(parameters, getBusinessObjectFactory());
        return;
    }

    public void deleteEmailOptOut(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName() + ": Deleting EmailOptOut");
        EmailOptOut emailOptOut =  getBusinessObjectFactory().createObject(EmailOptOut.class);
        BeanUtils.copyProperties(emailOptOut, parameters);
        EmailOptOutDAO emailOptOutDAO =  getDaoFactory().createDAO(EmailOptOutDAO.class);
        emailOptOutDAO.setEmailOptOut(emailOptOut);
        emailOptOutDAO.deleteEmailOptOut(true);
        return;
    }

	public Collection<EmailOptOut> loadAllEmailOptOuts() throws Exception {
		if (log.isInfoEnabled() && getUser().getAdministrator() != null)
			log.info(getUser().getAdministrator().getUserName() + ": Loading all EmailOptOuts");
		EmailOptOutGatewayDAO gatewayDAO =  getDaoFactory().createDAO(EmailOptOutGatewayDAO.class);
		return gatewayDAO.loadAllEmailOptOuts();
	}

	public Integer optOutsCountByEmailAndType(String type, String emailAddress) throws Exception {
		EmailOptOutGatewayDAO gatewayDAO = (EmailOptOutGatewayDAO) getDaoFactory().createDAO(
				"emailOptOutGatewayDAOImplementer");
		return gatewayDAO.optOutsCountByEmailAndType(type, emailAddress);
	}
}
