package com.softslate.commerce.businessobjects.order;

import java.util.Map;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.softslate.commerce.businessobjects.core.BaseBusinessProcessor;
import com.softslate.commerce.daos.order.OrderItemDAO;
import com.softslate.commerce.daos.order.OrderItemGatewayDAO;

/**
 * Processes business logic having to do with order items. Created in the Struts
 * layer in response to requests for viewing, editing, adding, and deleting
 * order items.
 * <p>
 * <code>BasicOrderItemProcessor</code> is the default implementation of the
 * <code>OrderItemProcessor</code> interface for the application.
 * 
 * @author David Tobey
 * 
 */
public class BasicOrderItemProcessor extends BaseBusinessProcessor implements
        OrderItemProcessor {

    static Log log = LogFactory.getLog(BasicOrderItemProcessor.class);

    public Map loadOrderItemsAndCount(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName()
                    + ": Loading order items and count");
        OrderItemGatewayDAO gatewayDAO =  getDaoFactory()
                .createDAO(OrderItemGatewayDAO.class);
        return gatewayDAO.loadOrderItemsAndCount(parameters);
    }

    public Map addOrderItem(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null) {
            String code = (String) parameters.get("code");
            log.info(getUser().getAdministrator().getUserName()
                    + ": Adding order item: " + code);
        }
        OrderItem orderItem =  getBusinessObjectFactory()
                .createObject(OrderItem.class);
        BeanUtils.copyProperties(orderItem, parameters);
        OrderDelivery orderDelivery =  getBusinessObjectFactory()
                .createObject(OrderDelivery.class);
        orderDelivery.setOrderDeliveryID(orderItem.getOrderDeliveryID());
        orderItem.setOrderDelivery(orderDelivery);
        OrderItemDAO dao = (OrderItemDAO) getDaoFactory().createDAO(
                "orderItemDAOImplementer");
        dao.setOrderItem(orderItem);
        dao.insertOrderItem(true);
        return null;
    }

    public OrderItem loadOrderItemFromID(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName()
                    + ": Loading order item from id");
        OrderItem orderItem =  getBusinessObjectFactory()
                .createObject(OrderItem.class);
        OrderItemDAO dao = (OrderItemDAO) getDaoFactory().createDAO(
                "orderItemDAOImplementer");
        BeanUtils.copyProperties(orderItem, parameters);
        dao.setOrderItem(orderItem);
        dao.loadOrderItemFromID();
        return dao.getOrderItem();
    }

    public Map editOrderItem(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null) {
            String code = (String) parameters.get("code");
            log.info(getUser().getAdministrator().getUserName()
                    + ": Editing order item: " + code);
        }
        OrderItem orderItem =  getBusinessObjectFactory()
                .createObject(OrderItem.class);
        BeanUtils.copyProperties(orderItem, parameters);
        OrderDelivery orderDelivery =  getBusinessObjectFactory()
                .createObject(OrderDelivery.class);
        orderDelivery.setOrderDeliveryID(orderItem.getOrderDeliveryID());
        orderItem.setOrderDelivery(orderDelivery);
        OrderItemDAO dao = (OrderItemDAO) getDaoFactory().createDAO(
                "orderItemDAOImplementer");
        dao.setOrderItem(orderItem);
        dao.updateOrderItem(true);
        return null;
    }

	public Map editDeleteOrderItems(Map parameters) throws Exception {
		if (log.isInfoEnabled() && getUser().getAdministrator() != null)
			log.info(getUser().getAdministrator().getUserName() + ": Editing/deleting multiple order items");
		OrderItemGatewayDAO dao =  getDaoFactory().createDAO(OrderItemGatewayDAO.class);
		Map results = dao.editDeleteOrderItems(parameters, getBusinessObjectFactory());
		return results;
	}

    public void deleteOrderItem(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null) {
            String code = (String) parameters.get("code");
            log.info(getUser().getAdministrator().getUserName()
                    + ": Deleting order item: " + code);
        }
        OrderItem orderItem =  getBusinessObjectFactory()
                .createObject(OrderItem.class);
        BeanUtils.copyProperties(orderItem, parameters);
        OrderItemDAO dao = (OrderItemDAO) getDaoFactory().createDAO(
                "orderItemDAOImplementer");
        dao.setOrderItem(orderItem);
        dao.deleteOrderItem(true);
        return;
    }
}
