package com.softslate.commerce.businessobjects.product;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BusinessObject;

/**
 * Interface representing a product setting within the system.
 * <p>
 * When the application needs to create an instance that implements
 * <code>sscProductSetting</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "productSettingImplementer" setting in the
 * <code>appComponents.properties</code> file.
 * <p>
 * The default "productSettingImplementer" is
 * {@link com.softslate.commerce.businessobjects.product.ProductSettingBean}.
 * 
 * @author David Tobey
 */
@Audited
@AuditTable("AudProductSetting")
public interface ProductSetting extends BusinessObject {
	abstract int getProductSettingID();

	abstract void setProductSettingID(int productSettingID);

	abstract Product getProduct();

	abstract void setProduct(Product product);

	abstract String getCode();

	abstract void setCode(String code);

	abstract String getDescription();

	abstract void setDescription(String description);

	abstract int getIntegerValue();

	abstract void setIntegerValue(int integerValue);

	abstract String getMediumValue();

	abstract void setMediumValue(String mediumValue);

	abstract String getName();

	abstract void setName(String name);

	abstract int getProductID();

	abstract void setProductID(int productID);

	abstract String getSmallValue();

	abstract void setSmallValue(String smallValue);

	abstract String getTextValue();

	abstract void setTextValue(String textValue);

	abstract String getType();

	abstract void setType(String type);

	abstract String getValueType();

	abstract void setValueType(String valueType);

	abstract String getValue();
}
