package com.softslate.commerce.businessobjects.product;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BusinessObject;

/**
 * Interface representing a sku discount in the system.
 * <p>
 * When the application needs to create an instance that implements
 * <code>SKUDiscount</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "skuDiscountImplementer" setting in the <code>appComponents.properties</code>
 * file.
 * <p>
 * The default "skuDiscountImplementer" is
 * {@link com.softslate.commerce.businessobjects.product.SKUDiscountBean}.
 * 
 * @author David Tobey
 * 
 */
@Audited
@AuditTable("AudSKUDiscount")
public interface SKUDiscount extends BusinessObject {

	abstract int getSkuDiscountID();

	abstract void setSkuDiscountID(int skuDiscountID);

	abstract int getDiscountID();

	abstract void setDiscountID(int discountID);

	abstract int getSkuID();

	abstract void setSkuID(int skuID);

	abstract Discount getDiscount();

	abstract void setDiscount(Discount discount);

	abstract SKU getSku();

	abstract void setSku(SKU sku);

}
