package com.softslate.commerce.businessobjects.shipping;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BusinessObject;

/**
 * Interface representing a shipping rate within the system.
 * <p>
 * When the application needs to create an instance that implements
 * <code>sscShippingRate</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "shippingRateImplementer" setting in the
 * <code>appComponents.properties</code> file.
 * <p>
 * The default "shippingRateImplementer" is
 * {@link com.softslate.commerce.businessobjects.shipping.ShippingRateBean}.
 * 
 * @author David Tobey
 * 
 */
@Audited
@AuditTable("AudShippingRate")
public interface ShippingRate extends BusinessObject {
	abstract int getShippingRateID();

	abstract void setShippingRateID(int shippingRateID);

	abstract Double getAmount();

	abstract void setAmount(Double amount);

	abstract Double getCeiling();

	abstract void setCeiling(Double ceiling);

	abstract Double getFloor();

	abstract void setFloor(Double floor);

	abstract boolean getIsActive();

	abstract void setIsActive(boolean isActive);

	abstract int getShippingMethodID();

	abstract void setShippingMethodID(int shippingMethodID);

	abstract ShippingMethod getShippingMethod();

	abstract void setShippingMethod(ShippingMethod shippingMethod);
}
