package com.softslate.commerce.customer.core;

import java.util.Locale;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.tiles.ComponentContext;
import org.apache.struts.tiles.actions.TilesAction;
import org.apache.struts.util.MessageResources;
import com.softslate.commerce.businessobjects.core.User;

/**
 * The Tiles contoller action that is used by the default "baseLayout",
 * "baseLeftLayout", and "baseCenterLayout" Tiles definitions. This controller
 * handles various aspects of the request that correspond to the specific page
 * the request is ending up on such as the welcome page, product page, category
 * page, etc.
 * 
 * @author David Tobey
 */
public class LayoutAction extends TilesAction {
	static Log log = LogFactory.getLog(LayoutAction.class);

	/**
	 * Runs as a request is forwarded to a Tiles definition. In particular, this
	 * method sets the page title for the request. This is the string used in
	 * the &lt;title&gt; tag of the HTML's &lt;head&gt; section. In addition, it
	 * populates the RequestLog object's customerID, customerUserName, orderID,
	 * orderNumber, administratorID, and/or administratorUserName with values if
	 * they have been populated during the course of the request.
	 */
	public ActionForward execute(ComponentContext context,
			ActionMapping mapping, ActionForm form, HttpServletRequest request,
			HttpServletResponse response) throws Exception {

		// Set the page title.
		if (log.isDebugEnabled())
			log.debug("Setting the page title.");
		String pageTitleKey = (String) context.getAttribute("pageTitleKey");
		if (pageTitleKey != null) {

			// Find the user's Locale to look up the page title.
			if (log.isDebugEnabled())
				log.debug("Page title key: " + pageTitleKey);
			Locale locale = null;
			if (request.getSession() != null) {
				User user = (User) request.getSession().getAttribute("user");
				if (user != null) {
					locale = user.getLocale();
				}
			}
			if (locale == null) {
				locale = Locale.getDefault();
			}

			// Append the page title to the title tag
			Boolean dontAppend = (Boolean) request
					.getAttribute("dontAppendToTitleTag");
			if (dontAppend == null || !dontAppend.booleanValue()) {
				String subTitle = getMessage(pageTitleKey, locale);
				request.setAttribute("htmlHeadTitle", request
						.getAttribute("htmlHeadTitle")
						+ " - " + subTitle);
			}
		}

		return null;
	}

	/**
	 * Look up and return a message from a given bundle among the Struts
	 * <code>MessageResources</code> objects in the application scope.
	 * 
	 * @param key
	 *            Message key to be looked up and returned.
	 * @param locale
	 *            The locale to look the message up with.
	 * @return The message, or <code>null</code> if the message can't be found.
	 */
	public String getMessage(String key, Locale locale) {
		// Load in the Locale and MessageResources
		ServletContext servletContext = getServlet().getServletContext();
		MessageResources resources = (MessageResources) servletContext
				.getAttribute("/core");
		String message = resources.getMessage(locale, key);
		if (message == null) {
			message = "";
		}
		return message;
	}
}
