package com.softslate.commerce.customer.customer;

import java.util.Collection;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.customer.Customer;
import com.softslate.commerce.businessobjects.order.Order;
import com.softslate.commerce.businessobjects.payment.authorizeNetCIM.AuthorizeNetCIMPaymentProfileMin;
import com.softslate.commerce.businessobjects.payment.authorizeNetCIM.AuthorizeNetCIMProcessor;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Ajax loading of profiles for API calls only.
 * 
 * @author Jason McWilliams
 * 
 */
public class LoadCIMProfilesAction extends BaseAction {

	static Log log = LogFactory.getLog(LoadCIMProfilesAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isInfoEnabled())
			log.info("Starting action.");

		AccountCIMManageProfilesForm baseForm = (AccountCIMManageProfilesForm) form;
		baseForm.setServlet(getServlet());
		baseForm.initializeProperties(mapping, request);

		synchronized (request.getSession()) {
			Properties appComponents = (Properties) getServlet().getServletContext().getAttribute("appComponents");
			String activePaymentProcessors = appComponents.getProperty("activePaymentProcessors");
			if (!activePaymentProcessors.contains("AuthorizeNetCIMProcessor")) {
				if (log.isInfoEnabled())
					log.info("CIM is not an active payment processor.");
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
						new ActionMessage("errors.cimManageProfilesNotAllowed"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
				return mapping.findForward("failure");
			}

			// Check Settings
			String authorizeNetCIMHostedMethod = (String) baseForm.getSettings()
					.getValue("authorizeNetCIMHostedMethod");
			if (!"API Only".equals(authorizeNetCIMHostedMethod)) {
				if (log.isInfoEnabled())
					log.info("API Only is not turned on");
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
						new ActionMessage("errors.cimManageProfilesNotAllowedAPI"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
				return mapping.findForward("failure");
			}

			// Set this to help decide what to show in the ajax templates
			baseForm.getRequest().setAttribute("useCIMAPI", true);
			baseForm.getRequest().setAttribute("fromPage", baseForm.getFromPage());

			Customer customer = baseForm.getUser().getCustomer();
			Order order = baseForm.getUser().getOrder();
			AuthorizeNetCIMProcessor cimProcessor =  baseForm.getBusinessObjectFactory()
					.createObject(AuthorizeNetCIMProcessor.class);
			cimProcessor.initialize();
			Collection<AuthorizeNetCIMPaymentProfileMin> paymentProfiles = cimProcessor.findPaymentProfiles(customer,
					order);
			if (paymentProfiles != null && paymentProfiles.size() > 0) {
				baseForm.getRequest().setAttribute("cimPaymentProfiles", paymentProfiles);
				return mapping.findForward("success");
			} else {
				if (log.isInfoEnabled()) {
					log.info("No payment profiles to show.");
				}
				return mapping.findForward("success");
			}
		}
	}
}
