package com.softslate.commerce.customer.payment;

import com.softslate.commerce.administrator.ordermanagement.OrderManagementUtils;
import com.softslate.commerce.businessobjects.customer.Customer;
import com.softslate.commerce.businessobjects.customer.CustomerProcessor;
import com.softslate.commerce.businessobjects.order.Order;
import com.softslate.commerce.businessobjects.order.OrderBean;
import com.softslate.commerce.businessobjects.order.OrderProcessor;
import com.softslate.commerce.businessobjects.payment.AuthorizeNetDPMProcessor;
import com.softslate.commerce.customer.core.ActionUtils;
import com.softslate.commerce.customer.core.BaseForm;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import com.softslate.commerce.customer.order.CheckoutAction;
import java.util.HashMap;
import java.util.Map;
import net.authorize.ResponseField;
import net.authorize.sim.Result;

/**
 * Struts action class used for the relay response from authorize. Used for
 * requests to "/AuthorizeNetDPM.do".
 * <p>
 * The <code>execute</code> method is going to create the relay response page.
 * 
 * @author Tony Zakula
 */

public class AuthorizeNetDPMRelayResponseAction extends CheckoutAction {

	static Log log = LogFactory
			.getLog(AuthorizeNetDPMRelayResponseAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isInfoEnabled())
			log.info("Starting AuthorizeNETDPM Relay Response Action.");

		// Initialize the BaseForm
		BaseForm baseForm = new BaseForm();
		baseForm.initializeProperties(mapping, request);

		String apiLoginId = (String) baseForm.getSettings().getValue(
				"authorizeNetDPMLoginID");
		String receiptPageUrl = baseForm.getSettings().getValue(
				"customerSecureURL")
				+ "/AuthorizeNetDPM.do";
		String completeOrder = (String) baseForm.getSettings().getValue(
				"authorizeNetDPMDelayOrderProcessing");

		synchronized (baseForm.getRequest().getSession()) {
			/*
			 * MD5HashKey is API Login ID. We do not accomodate a separate hash
			 * key at this time.
			 */
			String MD5HashKey = apiLoginId;
			Result result = Result.createResult(apiLoginId, MD5HashKey,
					request.getParameterMap());
			// build receipt url buffer
			StringBuffer receiptUrlBuffer = new StringBuffer(receiptPageUrl);
			String returnURL = "";
			// Check for a result
			ActionUtils actionUtils = (ActionUtils) baseForm
					.getBusinessObjectFactory().createUtilsObject(
							"actionUtilsImplementer");
			Map parameters = actionUtils.buildParameterMap(request);
			String responseCode = (String) parameters
					.get(ResponseField.RESPONSE_CODE.getFieldName());
			String responseReasonText = (String) parameters
					.get(ResponseField.RESPONSE_REASON_TEXT.getFieldName());
			if (result != null) {
				if (result.isApproved()
						|| (responseCode.equals("1") && responseReasonText
								.indexOf("This transaction has been approved") != -1)) {
					// We'll use the common checkout methods defined in
					// ActionUtils, and OrderProcessor
					OrderManagementUtils orderManagement = (OrderManagementUtils) baseForm
							.getBusinessObjectFactory().createUtilsObject(
									"orderManagementUtilsImplementer");
					OrderProcessor orderProcessor = (OrderProcessor) baseForm
							.getBusinessObjectFactory().createObject(
									"orderProcessorImplementer");
					CustomerProcessor customerProcessor = (CustomerProcessor) baseForm
							.getBusinessObjectFactory().createObject(
									"customerProcessorImplementer");
					// Load the order being edited
					if (log.isDebugEnabled())
						log.debug("Loading the order");
					// Now get the order id
					String orderID = (String) parameters
							.get(ResponseField.INVOICE_NUMBER.getFieldName());
					parameters.put("orderID", orderID);

					if (completeOrder.equals("1")) {
						Order order = orderProcessor
								.loadOrderFromID(parameters);
						baseForm.getRequest().setAttribute("order", order);
						if (order == null) {
							if (log.isErrorEnabled())
								log.error("Authorize approved transaction, but invalid order"
										+ " number! OrderID  " + orderID);
							returnURL = processError(result, receiptUrlBuffer,
									"failure");
							request.setAttribute("ReturnURL", returnURL);
							return mapping.findForward("successNoEmails");
						}

						// Set the session's order, customer, and
						// enteredCouponCodes
						baseForm.getUser().setOrder(order);
						baseForm.getUser().setEnteredCouponCodes(
								orderManagement.findCouponCodes(order));

						// Load the customer associated with the order
						if (order.getCustomerID() != null
								&& order.getCustomerID().intValue() != 0) {
							Map customerID = new HashMap();
							customerID.put("customerID", order.getCustomerID());
							Customer customer = customerProcessor
									.loadCustomerFromID(customerID);
							baseForm.getUser().setCustomer(customer);
						} else {
							baseForm.getUser().setCustomer(null);
						}
					} // end check for complete order now
					else { // We still need an order object to insert the
							// payment
						Order order = new OrderBean();
						order.setOrderID(Integer.parseInt(orderID));
						baseForm.getUser().setOrder(order);
					}

					// Update the payment
					AuthorizeNetDPMProcessor processor = (AuthorizeNetDPMProcessor) baseForm
							.getBusinessObjectFactory().createObject(
									"authorizeNetDPMProcessorImplementer");
					// Process the results
					Map results = processor.process(parameters);
					// Now check the result codes to see what happened
					String resultCode = (String) results.get("resultCode");

					if (resultCode.equals("0")) {
						// We have a successful transaction
						if (log.isInfoEnabled())
							log.info("DPM processing successful.");
						if (completeOrder.equals("1")) {
							processOrderComplete(baseForm);
						}
						returnURL = processSuccess(result, receiptUrlBuffer);
						request.setAttribute("ReturnURL", returnURL);
					}
					if (resultCode.equals("1")) {
						// We have a general exception
						if (log.isInfoEnabled())
							log.info("DPM processing failed - exception.");
						returnURL = processError(result, receiptUrlBuffer,
								"failure");
						request.setAttribute("ReturnURL", returnURL);
						return mapping.findForward("successNoEmails");
					}
					if (resultCode.equals("2")) {
						// We have a validation error we designed
						if (log.isInfoEnabled())
							log.info("DPM processing failed - validation error.");
						returnURL = processError(result, receiptUrlBuffer,
								"failure");
						request.setAttribute("ReturnURL", returnURL);
						return mapping.findForward("successNoEmails");
					}

				} // end check for approved transaction
				else {
					// we have a transaction, but it was not approved
					returnURL = processError(result, receiptUrlBuffer,
							"success");
					request.setAttribute("ReturnURL", returnURL);
					if (log.isDebugEnabled())
						log.debug("ReturnURL = " + returnURL);
					return mapping.findForward("successNoEmails");
				} // end else check for approved transaction
			} else {
				// result is null
				receiptUrlBuffer.append("?ssStatus=failure");
				returnURL = receiptUrlBuffer.toString();
				request.setAttribute("ReturnURL", returnURL);
				if (log.isWarnEnabled())
					log.warn("AuthorizeDPM result was null on relay response");
				return mapping.findForward("successNoEmails");
			}

			if (log.isInfoEnabled())
				log.info("ReturnURL - " + returnURL);
			// We should only ever get here if everything is a success and we
			// plan to complete the order.
			String email = (String) baseForm.getSettings().getValue(
					"authorizeNetDPMEmailCustomerConfirmationWhen");
			// a value of 1 says send emails now.
			if (email.equals("1") && completeOrder.equals("1")) {
				// We need to set some attributes for the relay response in case
				// we need to send emails.
				request.setAttribute("baseForm", baseForm);
				request.setAttribute("user", baseForm.getUser());
				return mapping.findForward("success");
			} else {
				return mapping.findForward("successNoEmails");
			}

		} // End syncro method
	} // End execute

	private String processError(Result result, StringBuffer receiptUrlBuffer,
			String ssStatus) {
		// This method is for generating error information to send back to
		// the SoftSlate return action
		receiptUrlBuffer.append("?");
		receiptUrlBuffer.append(ResponseField.RESPONSE_CODE.getFieldName())
				.append("=");
		receiptUrlBuffer.append(result.getResponseCode().getCode());
		receiptUrlBuffer.append("&");
		receiptUrlBuffer.append(
				ResponseField.RESPONSE_REASON_CODE.getFieldName()).append("=");
		receiptUrlBuffer.append(result.getReasonResponseCode()
				.getResponseReasonCode());
		receiptUrlBuffer.append("&");
		receiptUrlBuffer.append(
				ResponseField.RESPONSE_REASON_TEXT.getFieldName()).append("=");
		receiptUrlBuffer.append(result.getResponseMap().get(
				ResponseField.RESPONSE_REASON_TEXT.getFieldName()));

		// This is for communication with our SoftSlate Return Action
		receiptUrlBuffer.append("&ssStatus=" + ssStatus);

		return receiptUrlBuffer.toString();
	}

	private String processSuccess(Result result, StringBuffer receiptUrlBuffer) {

		receiptUrlBuffer.append("?");
		receiptUrlBuffer.append(ResponseField.RESPONSE_CODE.getFieldName())
				.append("=");
		receiptUrlBuffer.append(result.getResponseCode().getCode());
		receiptUrlBuffer.append("&");
		receiptUrlBuffer.append(
				ResponseField.RESPONSE_REASON_CODE.getFieldName()).append("=");
		receiptUrlBuffer.append(result.getReasonResponseCode()
				.getResponseReasonCode());
		receiptUrlBuffer.append("&");
		receiptUrlBuffer.append(
				ResponseField.RESPONSE_REASON_TEXT.getFieldName()).append("=");
		receiptUrlBuffer.append(result.getResponseMap().get(
				ResponseField.RESPONSE_REASON_TEXT.getFieldName()));
		// Below is specific to approved transactions. Although, technically,
		// a transaction ID is assigned to failed transactions as well.
		receiptUrlBuffer.append("&")
				.append(ResponseField.TRANSACTION_ID.getFieldName())
				.append("=");
		receiptUrlBuffer.append(result.getResponseMap().get(
				ResponseField.TRANSACTION_ID.getFieldName()));
		// This is for communication with our SoftSlate Return Action
		receiptUrlBuffer.append("&ssStatus=success");

		return receiptUrlBuffer.toString();
	}

}
