package com.softslate.commerce.daos.customer;

import java.util.Collection;

import com.softslate.commerce.businessobjects.customer.Customer;
import com.softslate.commerce.daos.core.DAOInterface;

/**
 * Interface for a DAO to manage the <code>sscCustomer</code> table of the
 * database.
 * 
 * @author David Tobey
 */
public interface CustomerDAO extends DAOInterface {
	abstract Customer getCustomer();

	abstract void setCustomer(Customer customer);

	abstract int getUserNameCount() throws Exception;

	abstract int getUserNameCount(boolean commit) throws Exception;

	abstract void insertCustomer() throws Exception;

	abstract void insertCustomer(boolean commit) throws Exception;

	abstract void updateCustomer() throws Exception;

	abstract void updateCustomer(boolean commit) throws Exception;

	abstract void updateCustomer(boolean commit, boolean forcePassword)
			throws Exception;

	/**
	 * Assuming the userName property has been set, queries the database for a
	 * customer record that matches.
	 */
	abstract void loadFromUserName() throws Exception;

	/**
	 * Assuming the userName and password properties have been set, queries the
	 * database for a customer record that matches.
	 */
	abstract void loadFromUserNameAndPassword() throws Exception;

	/**
	 * Assuming the autoLoginToken has been set, queries the database for a
	 * customer record that matches.
	 */
	abstract void loadFromAutoLoginToken() throws Exception;

	/**
	 * Populate a collection of CustomerAddress objects, one for each of the
	 * addresses associated with this customer.
	 */
	abstract Collection loadAddressCollection() throws Exception;
	
	/**
	 * Populate a collection of Order objects, one for each order in this
	 * customer's order history.
	 */
	abstract Collection loadOrderHistory() throws Exception;

	/**
	 * Populate a collection of Maps for each file available for the customer to
	 * download.
	 */
	abstract Collection loadDownloadFiles() throws Exception;

	/**
	 * Return a collection of Order objects, one for each cart that this
	 * customer has saved (identified by having a status of "Saved").
	 */
	abstract Collection loadSavedCarts() throws Exception;

	abstract void loadCustomerFromID() throws Exception;

	abstract void deleteCustomer() throws Exception;

	abstract void deleteCustomer(boolean commit) throws Exception;

	abstract Collection loadCustomerWishLists() throws Exception;

	abstract void loadCustomerByPasswordToken() throws Exception;

}
