package com.softslate.commerce.daos.email;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.HibernateException;
import org.hibernate.Session;

import com.softslate.commerce.businessobjects.email.EmailOptOut;
import com.softslate.commerce.daos.core.BaseDAO;
import com.softslate.commerce.daos.core.DAOInterface;
import com.softslate.commerce.daos.core.DataAccessException;


/**
 * Generic DAO to manage the <code>sscEmailOptOut</code> table of the
 * database.
 * 
 */
public class EmailOptOutDAOHibernate extends BaseDAO implements DAOInterface, EmailOptOutDAO {

    static Log log = LogFactory.getLog(EmailOptOutDAOHibernate.class);

    private EmailOptOut emailOptOut = null;

    public EmailOptOut getEmailOptOut() {
        return (this.emailOptOut);
    }

    public void setEmailOptOut(EmailOptOut emailOptOut) {
        this.emailOptOut = emailOptOut;
    }

    public void loadEmailOptOutFromID() throws Exception {
        Session session = getDaoFactory().startSession();
        try {
            EmailOptOut record = (EmailOptOut) session.get(
                    EmailOptOut.class, new Integer(getEmailOptOut()
                            .getEmailOptOutID()));
            PropertyUtils.copyProperties(getEmailOptOut(), record);
            setEmailOptOut(record);
        } catch (HibernateException he) {
            if (log.isErrorEnabled())
                log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }

    public void insertEmailOptOut() throws Exception {
        insertEmailOptOut(false);
    }

    public void insertEmailOptOut(boolean commit) throws Exception {
        Session session = getDaoFactory().startSession();
        try {
			getEmailOptOut().setCreatedTime(formatDateTime(new java.util.Date()));
            session.save(getEmailOptOut());
            if (commit) {
                getDaoFactory().commitTransaction();
            }
			if (getEmailOptOut() != null) {
				session.evict(getEmailOptOut());
			}
			loadEmailOptOutFromID();
        } catch (HibernateException he) {
            if (log.isErrorEnabled()) log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }

    public void updateEmailOptOut() throws DataAccessException {
        updateEmailOptOut(false);
    }

    public void updateEmailOptOut(boolean commit) throws DataAccessException {
        Session session = getDaoFactory().startSession();
        try {
            session.update(getEmailOptOut());
            if (commit) {
                getDaoFactory().commitTransaction();
            }
        } catch (HibernateException he) {
            if (log.isErrorEnabled()) log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }

    public void deleteEmailOptOut() throws Exception {
        deleteEmailOptOut(false);
    }

    public void deleteEmailOptOut(boolean commit) throws Exception {
        Session session = getDaoFactory().startSession();
        try {
            setEmailOptOut((EmailOptOut) session.load(EmailOptOut.class,
                    new Integer(getEmailOptOut().getEmailOptOutID())));
            session.delete(getEmailOptOut());
            if (commit) {
                getDaoFactory().commitTransaction();
            }
        } catch (HibernateException he) { log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }
}
