package com.softslate.commerce.daos.product;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;

import com.softslate.commerce.businessobjects.product.Attribute;
import com.softslate.commerce.daos.core.BaseDAO;
import com.softslate.commerce.daos.core.DAOInterface;
import com.softslate.commerce.daos.core.DataAccessException;

/**
 * Generic DAO to manage the <code>sscAttribute</code> table of the database.
 * 
 * @author David Tobey
 * 
 */
public class AttributeDAOHibernate extends BaseDAO implements DAOInterface,
		AttributeDAO {

	static Log log = LogFactory.getLog(AttributeDAOHibernate.class);

	private Attribute attribute = null;

	public Attribute getAttribute() {
		return (this.attribute);
	}

	public void setAttribute(Attribute attribute) {
		this.attribute = attribute;
	}

	public void loadAttributeFromID() throws Exception {
		Session session = getDaoFactory().startSession();
		try {
			Attribute attribute = (Attribute) session.get(Attribute.class,
					new Integer(getAttribute().getAttributeID()));
			PropertyUtils.copyProperties(getAttribute(), attribute);
			setAttribute(attribute);
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

	public void insertAttribute() throws DataAccessException {
		insertAttribute(false);
	}

	public void insertAttribute(boolean commit) throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			session.save(getAttribute());
			if (commit) {
				getDaoFactory().commitTransaction();
			}
			evictCache();
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

	public void updateAttribute() throws DataAccessException {
		updateAttribute(false);
	}

	public void updateAttribute(boolean commit) throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			session.update(getAttribute());
			if (commit) {
				getDaoFactory().commitTransaction();
			}
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

	public void deleteAttribute() throws DataAccessException {
		deleteAttribute(false);
	}

	public void deleteAttribute(boolean commit) throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			setAttribute((Attribute) session.load(Attribute.class, new Integer(
					getAttribute().getAttributeID())));
			session.delete(getAttribute());
			if (commit) {
				getDaoFactory().commitTransaction();
			}
			evictCache();
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}
	
	public void loadAttributeFromCode() throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			Query q = getNamedQuery(session, "attribute.selectAttributeFromCode");
			q.setString("code", this.getAttribute().getAttributeCode());
			Attribute loadedAttribute = (Attribute) q.uniqueResult();
			setAttribute(loadedAttribute);
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}
	
	
	public Object loadObject(Object object) throws Exception 
	{
	  if (null != object && object instanceof Attribute)
	  {
		  this.setAttribute((Attribute)object);
		  if (0 != this.getAttribute().getAttributeID())
		  {			  
			  this.loadAttributeFromID();
		  }
		  else if (null != this.getAttribute().getAttributeCode())
		  {
			  this.loadAttributeFromCode();
		  }
		  return this.getAttribute();
	  }
	  return null;
	}

	public boolean deleteObject(Object object, boolean commit) throws Exception 
	{
		  if (null != object && object instanceof Attribute)
		  {
				  this.setAttribute((Attribute)object);
				  this.deleteAttribute(commit);
				  return true;
		  }
		  return false;
	}

	public Object insertObject(Object object, boolean commit) throws Exception 
	{
		  if (null != object && object instanceof Attribute)
		  {
			this.setAttribute((Attribute)object);
			this.insertAttribute(commit);
			return this.getAttribute();
		  }
		  return null;
	}

	public Object updateObject(Object object, boolean commit) throws Exception 
	{
	  if (null != object && object instanceof Attribute)
	  {
			  this.setAttribute((Attribute)object);
			  this.updateAttribute(commit);
			  return this.getAttribute();
	  }
	  return null;
	  
	}
}
