package com.softslate.commerce.installer;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.customer.core.BaseAction;
import com.softslate.commerce.customer.core.BaseDynaForm;

/**
 * 
 * @author David Tobey
 */
public class LockInstallerAction extends BaseAction {

	static Log log = LogFactory.getLog(LockInstallerAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");
		ActionErrors errors = new ActionErrors();
		ActionMessages messages = new ActionMessages();
		BaseDynaForm baseForm = (BaseDynaForm) form;

		if (!baseForm.get("lockInstaller").equals("false")) {
			// Create an output stream to the appSettings.properties file.
			String appSettingsPropertiesFile = "appSettings.properties";
			if (System.getProperty("appSettings.configuration") != null) {
				appSettingsPropertiesFile = System
						.getProperty("appSettings.configuration");
			}
			String pathToProperties = getServlet().getServletContext()
					.getRealPath(
							"/WEB-INF/classes/" + appSettingsPropertiesFile);
			if (pathToProperties == null) {
				errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
						"installer.warError", pathToProperties));
				addErrors(request, errors);
				if (!messages.isEmpty())
					addMessages(request, messages);
				return mapping.findForward("error");
			}
			File propertiesFile = new File(pathToProperties);
			FileOutputStream fos = new FileOutputStream(propertiesFile);

			// Copy the sqlManager parameters to a Properties object.
			if (log.isDebugEnabled())
				log.debug("Copy app settings to a Properties object.");
			Properties properties = (Properties) getServlet()
					.getServletContext().getAttribute("appSettings");
			properties.setProperty("lockInstaller", "locked");

			// Attempt to write settings to the file, including the
			// lockInstaller
			if (log.isDebugEnabled())
				log
						.debug("Attempting to write settings to "
								+ pathToProperties);
			try {
				properties.store(fos, "Generated by installer.");
			} catch (FileNotFoundException fnfe) {
				errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
						"installer.fileNotFoundError", pathToProperties));
				addErrors(request, errors);
				if (!messages.isEmpty())
					addMessages(request, messages);
				return mapping.findForward("error");
			}
			messages.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
					"installer.locked", pathToProperties));

			// In case we're in an environment with an src folder, save
			// the file to the src area too.
			String pathToPropertiesSrc = null;
			try {
				pathToPropertiesSrc = getServlet().getServletContext()
						.getRealPath(
								"/WEB-INF/src/" + appSettingsPropertiesFile);
				if (pathToPropertiesSrc != null) {
					File propertiesFileSrc = new File(pathToPropertiesSrc);
					if (properties != null && propertiesFileSrc.exists()) {
						FileOutputStream fos2 = new FileOutputStream(
								propertiesFileSrc);
						properties.store(fos2, "Generated by installer.");
					}
				}
			} catch (Exception e) {
				if (log.isWarnEnabled())
					log.warn("Error attempting to write settings to "
							+ pathToPropertiesSrc, e);
			}

			if (!messages.isEmpty())
				addMessages(request, messages);
		}
		if (log.isDebugEnabled())
			log.debug("Finished with Action.");
		return mapping.findForward("success");
	}

}
